<?php

namespace MediaTranscription\MediaTranscription\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use MediaTranscription\MediaTranscription\Models\Transcription;

class TranscriptionPolicy
{

    /**
     * Determine if the given user can view the transcription.
     *
     * @param UserPolicyInterface $authUser
     * @param Transcription $transcription
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Transcription $transcription)
    {
        if ($authUser->canDo('media_transcription.transcription.view') && $authUser->isAdmin()) {
            return true;
        }

        return $transcription->user_id == user_id() && $transcription->user_type == user_type();
    }

    /**
     * Determine if the given user can create a transcription.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('media_transcription.transcription.create');
    }

    /**
     * Determine if the given user can update the given transcription.
     *
     * @param UserPolicyInterface $authUser
     * @param Transcription $transcription
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Transcription $transcription)
    {
        if ($authUser->canDo('media_transcription.transcription.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $transcription->user_id == user_id() && $transcription->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given transcription.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Transcription $transcription)
    {
        return $transcription->user_id == user_id() && $transcription->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given transcription.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Transcription $transcription)
    {
        if ($authUser->canDo('media_transcription.transcription.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given transcription.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Transcription $transcription)
    {
        if ($authUser->canDo('media_transcription.transcription.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
