<?php

namespace MediaTranscription\MediaTranscription\Providers;

use Illuminate\Support\ServiceProvider;
use MediaTranscription\MediaTranscription\MediaTranscriptions;

class MediaTranscriptionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'media_transcription');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'media_transcription');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\MediaTranscription\MediaTranscription\Providers\AuthServiceProvider::class);
        $this->app->register(\MediaTranscription\MediaTranscription\Providers\RouteServiceProvider::class);
        // $this->app->register(\MediaTranscription\MediaTranscription\Providers\EventServiceProvider::class);
        // $this->app->register(\MediaTranscription\MediaTranscription\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('media_transcription.media_transcription', function($app)
        {
            return $this->app->make(MediaTranscriptions::class);
        });
    }



    /**
     * Merges user's and media_transcription's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'media_transcription.media_transcription'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/transcription.php', 'media_transcription.media_transcription.transcription'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \MediaTranscription\MediaTranscription\Commands\MediaTranscription::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['media_transcription.media_transcription'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('media_transcription/media_transcription')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/media_transcription')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/media_transcription')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
